@@ -22,23 +22,24 @@ type releaseCmd struct {
 }
 
 type releaseOpts struct {
-	config            string
-	releaseNotesFile  string
-	releaseNotesTmpl  string
-	releaseHeaderFile string
-	releaseHeaderTmpl string
-	releaseFooterFile string
-	releaseFooterTmpl string
-	autoSnapshot      bool
-	snapshot          bool
-	skipPublish       bool
-	skipSign          bool
-	skipValidate      bool
-	skipAnnounce      bool
-	rmDist            bool
-	deprecated        bool
-	parallelism       int
-	timeout           time.Duration
+	config             string
+	releaseNotesFile   string
+	releaseNotesTmpl   string
+	releaseHeaderFile  string
+	releaseHeaderTmpl  string
+	releaseFooterFile  string
+	releaseFooterTmpl  string
+	autoSnapshot       bool
+	snapshot           bool
+	skipPublish        bool
+	skipSign           bool
+	skipValidate       bool
+	skipAnnounce       bool
+	skipSBOMCataloging bool
+	rmDist             bool
+	deprecated         bool
+	parallelism        int
+	timeout            time.Duration
 }
 
 func newReleaseCmd() *releaseCmd {
@@ -82,6 +83,7 @@ func newReleaseCmd() *releaseCmd {
 	cmd.Flags().BoolVar(&root.opts.skipPublish, "skip-publish", false, "Skips publishing artifacts")
 	cmd.Flags().BoolVar(&root.opts.skipAnnounce, "skip-announce", false, "Skips announcing releases (implies --skip-validate)")
 	cmd.Flags().BoolVar(&root.opts.skipSign, "skip-sign", false, "Skips signing artifacts")
+	cmd.Flags().BoolVar(&root.opts.skipSBOMCataloging, "skip-sbom", false, "Skips cataloging artifacts")
 	cmd.Flags().BoolVar(&root.opts.skipValidate, "skip-validate", false, "Skips git checks")
 	cmd.Flags().BoolVar(&root.opts.rmDist, "rm-dist", false, "Removes the dist folder")
 	cmd.Flags().IntVarP(&root.opts.parallelism, "parallelism", "p", 0, "Amount tasks to run concurrently (default: number of CPUs)")
@@ -139,6 +141,7 @@ func setupReleaseContext(ctx *context.Context, options releaseOpts) *context.Con
 	ctx.SkipAnnounce = ctx.Snapshot || options.skipPublish || options.skipAnnounce
 	ctx.SkipValidate = ctx.Snapshot || options.skipValidate
 	ctx.SkipSign = options.skipSign
+	ctx.SkipSBOMCataloging = options.skipSBOMCataloging
 	ctx.RmDist = options.rmDist
 
 	// test only
