@@ -1,11 +1,13 @@
 package artifact
 
 import (
+	"encoding/json"
 	"fmt"
 	"os"
 	"path/filepath"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/golden"
 	"github.com/stretchr/testify/require"
 	"golang.org/x/sync/errgroup"
 )
@@ -67,6 +69,22 @@ func TestFilter(t *testing.T) {
 			Name: "checkzumm",
 			Type: Checksum,
 		},
+		{
+			Name:   "unibin-replaces",
+			Goos:   "darwin",
+			Goarch: "all",
+			Extra: map[string]interface{}{
+				ExtraReplaces: true,
+			},
+		},
+		{
+			Name:   "unibin-noreplace",
+			Goos:   "darwin",
+			Goarch: "all",
+			Extra: map[string]interface{}{
+				ExtraReplaces: false,
+			},
+		},
 	}
 	artifacts := New()
 	for _, a := range data {
@@ -74,7 +92,7 @@ func TestFilter(t *testing.T) {
 	}
 
 	require.Len(t, artifacts.Filter(ByGoos("linux")).items, 1)
-	require.Len(t, artifacts.Filter(ByGoos("darwin")).items, 0)
+	require.Len(t, artifacts.Filter(ByGoos("darwin")).items, 2)
 
 	require.Len(t, artifacts.Filter(ByGoarch("amd64")).items, 1)
 	require.Len(t, artifacts.Filter(ByGoarch("386")).items, 0)
@@ -85,7 +103,10 @@ func TestFilter(t *testing.T) {
 	require.Len(t, artifacts.Filter(ByType(Checksum)).items, 2)
 	require.Len(t, artifacts.Filter(ByType(Binary)).items, 0)
 
-	require.Len(t, artifacts.Filter(nil).items, 5)
+	require.Len(t, artifacts.Filter(OnlyReplacingUnibins).items, 6)
+	require.Len(t, artifacts.Filter(And(OnlyReplacingUnibins, ByGoos("darwin"))).items, 1)
+
+	require.Len(t, artifacts.Filter(nil).items, 7)
 
 	require.Len(t, artifacts.Filter(
 		And(
@@ -364,13 +385,20 @@ func TestTypeToString(t *testing.T) {
 		GoFishRig,
 		KrewPluginManifest,
 		ScoopManifest,
+		SBOM,
 	} {
 		t.Run(a.String(), func(t *testing.T) {
 			require.NotEqual(t, "unknown", a.String())
+			bts, err := a.MarshalJSON()
+			require.NoError(t, err)
+			require.Equal(t, []byte(`"`+a.String()+`"`), bts)
 		})
 	}
 	t.Run("unknown", func(t *testing.T) {
 		require.Equal(t, "unknown", Type(9999).String())
+		bts, err := Type(9999).MarshalJSON()
+		require.NoError(t, err)
+		require.Equal(t, []byte(`"unknown"`), bts)
 	})
 }
 
@@ -384,3 +412,130 @@ func TestPaths(t *testing.T) {
 	}
 	require.ElementsMatch(t, paths, artifacts.Paths())
 }
+
+func TestRefresher(t *testing.T) {
+	t.Run("ok", func(t *testing.T) {
+		artifacts := New()
+		path := filepath.Join(t.TempDir(), "f")
+		artifacts.Add(&Artifact{
+			Name: "f",
+			Path: path,
+			Type: Checksum,
+			Extra: map[string]interface{}{
+				"Refresh": func() error {
+					return os.WriteFile(path, []byte("hello"), 0o765)
+				},
+			},
+		})
+		artifacts.Add(&Artifact{
+			Name: "invalid",
+			Type: Checksum,
+			Extra: map[string]interface{}{
+				"Refresh": func() {
+					t.Fatalf("should not have been called")
+				},
+			},
+		})
+		artifacts.Add(&Artifact{
+			Name: "no refresh",
+			Type: Checksum,
+		})
+
+		for _, item := range artifacts.List() {
+			require.NoError(t, item.Refresh())
+		}
+
+		bts, err := os.ReadFile(path)
+		require.NoError(t, err)
+		require.Equal(t, "hello", string(bts))
+	})
+
+	t.Run("nok", func(t *testing.T) {
+		artifacts := New()
+		artifacts.Add(&Artifact{
+			Name: "fail",
+			Type: Checksum,
+			Extra: map[string]interface{}{
+				"ID": "nok",
+				"Refresh": func() error {
+					return fmt.Errorf("fake err")
+				},
+			},
+		})
+
+		for _, item := range artifacts.List() {
+			require.EqualError(t, item.Refresh(), `failed to refresh "fail": fake err`)
+		}
+	})
+
+	t.Run("not a checksum", func(t *testing.T) {
+		artifacts := New()
+		artifacts.Add(&Artifact{
+			Name: "will be ignored",
+			Type: Binary,
+			Extra: map[string]interface{}{
+				"ID": "ignored",
+				"Refresh": func() error {
+					return fmt.Errorf("err that should not happen")
+				},
+			},
+		})
+
+		for _, item := range artifacts.List() {
+			require.NoError(t, item.Refresh())
+		}
+	})
+}
+
+func TestVisit(t *testing.T) {
+	artifacts := New()
+	artifacts.Add(&Artifact{
+		Name: "foo",
+		Type: Checksum,
+	})
+	artifacts.Add(&Artifact{
+		Name: "foo",
+		Type: Binary,
+	})
+
+	t.Run("ok", func(t *testing.T) {
+		require.NoError(t, artifacts.Visit(func(a *Artifact) error {
+			require.Equal(t, "foo", a.Name)
+			return nil
+		}))
+	})
+
+	t.Run("nok", func(t *testing.T) {
+		require.EqualError(t, artifacts.Visit(func(a *Artifact) error {
+			return fmt.Errorf("fake err")
+		}), `fake err`)
+	})
+}
+
+func TestMarshalJSON(t *testing.T) {
+	artifacts := New()
+	artifacts.Add(&Artifact{
+		Name: "foo",
+		Type: Binary,
+		Extra: map[string]interface{}{
+			ExtraID: "adsad",
+		},
+	})
+	artifacts.Add(&Artifact{
+		Name: "foo",
+		Type: UploadableArchive,
+		Extra: map[string]interface{}{
+			ExtraID: "adsad",
+		},
+	})
+	artifacts.Add(&Artifact{
+		Name: "foo",
+		Type: Checksum,
+		Extra: map[string]interface{}{
+			ExtraRefresh: func() error { return nil },
+		},
+	})
+	bts, err := json.Marshal(artifacts.List())
+	require.NoError(t, err)
+	golden.RequireEqualJSON(t, bts)
+}
