@@ -1048,8 +1048,7 @@ func TestRunPipe(t *testing.T) {
 }
 
 func TestRunPipeWhileUsingBuildpacks(t *testing.T) {
-	testlib.CheckPath(t, "packs")
-
+	testlib.CheckPath(t, "pack")
 	type errChecker func(*testing.T, error)
 	shouldNotErr := func(t *testing.T, err error) {
 		t.Helper()
@@ -1059,7 +1058,6 @@ func TestRunPipeWhileUsingBuildpacks(t *testing.T) {
 	table := map[string]struct {
 		dockers             []config.Docker
 		manifests           []config.DockerManifest
-		env                 map[string]string
 		expect              []string
 		assertError         errChecker
 		pubAssertError      errChecker
@@ -1101,8 +1099,8 @@ func TestRunPipeWhileUsingBuildpacks(t *testing.T) {
 				Dist:        dist,
 				Dockers:     docker.dockers,
 			})
+
 			ctx.Parallelism = 1
-			ctx.Env = docker.env
 			ctx.Version = "1.0.0"
 			ctx.Git = context.GitInfo{
 				CurrentTag: "v1.0.0",
